==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Snap/SnapCoordinate/ts/SnapCoordinate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SnapCoordinate</name>
    <message>
        <location filename="../SnapCoordinate.js" line="+87"/>
        <source>Set coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Ustaw koordynować</translation>
    </message>
    <message>
        <location filename="../SnapCoordinate.ui" line="+17"/>
        <source>&amp;x:</source>
        <translatorcomment>--google--
Mnożnik &amp;X:</translatorcomment>
        <translation type="unfinished">x:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>X Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Współrzędna X</translatorcomment>
        <translation type="unfinished">Współrzędna X</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;y:</source>
        <translatorcomment>--google--
Mnożnik &amp;Y:</translatorcomment>
        <translation type="unfinished">y:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Y Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Współrzędna Y</translatorcomment>
        <translation type="unfinished">Współrzędna Y</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Tick for Relative Coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zaznacz na współrzędne względne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Relati&amp;ve</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Względny</translation>
    </message>
    <message>
        <location filename="../SnapCoordinateInit.js" line="+2"/>
        <source>&amp;Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Współrzędne</translatorcomment>
        <translation type="unfinished">&amp;Współrzędne</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Snap/SnapCoordinate/ts/SnapCoordinate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapCoordinate</name>
    <message>
        <location filename="../SnapCoordinate.js" line="+87"/>
        <source>Set coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ustal współrzędną</translation>
    </message>
    <message>
        <location filename="../SnapCoordinate.ui" line="+17"/>
        <source>&amp;x:</source>
        <translatorcomment>--google--
Mnożnik &amp;X:</translatorcomment>
        <translation>&amp;x:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>X Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Współrzędna X</translatorcomment>
        <translation>Współrzędna x</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;y:</source>
        <translatorcomment>--google--
Mnożnik &amp;Y:</translatorcomment>
        <translation>&amp;y:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Y Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Współrzędna Y</translatorcomment>
        <translation>Współrzędna y</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Tick for Relative Coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Używa współrzędnych względnych</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Relati&amp;ve</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Względna</translation>
    </message>
    <message>
        <location filename="../SnapCoordinateInit.js" line="+2"/>
        <source>&amp;Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Współrzędne</translatorcomment>
        <translation>&amp;Współrzędna</translation>
    </message>
</context>
</TS>
